%bcond_with bootstrap

Summary:        Fast Scanner Generator
Name:           jflex
Version:        1.7.0
Release:        5%{?dist}
License:        BSD
URL:            http://jflex.de/
Source0:        %{name}-%{version}-clean.tar.gz
Source1:        %{name}.1

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(java_cup:java_cup)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.ant:ant)
%endif

%if %{without bootstrap}
BuildRequires:  jflex
%endif

BuildArch:      noarch
ExclusiveArch:  %{java_arches} noarch

Requires:       javapackages-tools

%description
JFlex is a lexical analyzer generator (also known as scanner generator) for 
Java, written in Java.

A lexical analyzer generator takes as input a specification with a set of 
regular expressions and corresponding actions. It generates a program (a lexer)
that reads input, matches the input against the regular expressions in the 
spec file, and runs the corresponding action if a regular expression matched. 
Lexers usually are the first front-end step in compilers, matching keywords, 
comments, operators, etc, and generating an input token stream for parsers. 
Lexers can also be used for many other purposes.

JFlex lexers are based on deterministic finite automata (DFAs). They are fast, 
without expensive backtracking.

JFlex is designed to work together with the LALR parser generator CUP by Scott 
Hudson, and the Java modification of Berkeley Yacc BYacc/J by Bob Jamison. It 
can also be used together with other parser generators like ANTLR or as a 
standalone tool.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package provides %{summary}.



%prep
%setup -q
%mvn_file : %{name}
%pom_add_dep java_cup:java_cup

%pom_remove_plugin :jflex-maven-plugin
%pom_remove_plugin :cup-maven-plugin
%pom_remove_plugin :maven-shade-plugin
%pom_remove_dep :cup_runtime

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-surefire-plugin']/pom:configuration" "<argLine>-Xss16384k</argLine>"

%pom_xpath_remove "pom:plugin[pom:artifactId='maven-site-plugin']" parent.xml
%pom_xpath_remove "pom:plugin[pom:artifactId='fmt-maven-plugin']" parent.xml
%pom_xpath_remove "pom:plugin[pom:artifactId='cup-maven-plugin']" parent.xml
%pom_xpath_remove "pom:plugin[pom:artifactId='maven-shade-plugin']" parent.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='plexus-compiler-javac-errorprone']" parent.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='error_prone_core']" parent.xml
%pom_xpath_remove "pom:compilerId" parent.xml
%pom_xpath_remove "pom:compilerArgs" parent.xml

sed -i /%%inputstreamctor/d src/main/jflex/LexScan.flex



%build
%{?jpb_env}
cup -parser LexParse -interface -destdir src/main/java src/main/cup/LexParse.cup
jflex -d src/main/java/jflex --skel src/main/jflex/skeleton.nested src/main/jflex/LexScan.flex
%mvn_build



%install
%mvn_install

%jpackage_script jflex.Main "" "" jflex:java_cup jflex true

install -d -m 755 %{buildroot}%{_mandir}/man1
install -p -m 644 %{SOURCE1} %{buildroot}%{_mandir}/man1



%files -f .mfiles
%license COPYRIGHT
%doc doc
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*

%files javadoc
%license COPYRIGHT
%doc %{_javadocdir}/%{name}



%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.0-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Apr 21 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.7.0-2
- non-bootstrap

* Fri Apr 21 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.7.0-1
- initial
- we should bootstrap building because it dependence itsself
